=======
History
=======

0.0.1 (2018-10-12)
------------------

* First release on PyPI.

0.0.2 (2018-10-13)
------------------

* Emit error messages.

0.0.3 (2018-10-16)
------------------

* Add line magic usage
* Change to load_ext pattern

0.0.4 (2018-10-16)
------------------

* Add argparse parsing for line and cell magic
* Add --temp-dir option to reduce clutter
* Add --file_prefix for organization

0.0.5 (2018-10-16)
------------------

* Add Quickstart notebook as a demo
* Remove print statements introduced during debugging
